# JAX-IK
Official implementation for the paper: "Real-Time Inverse Kinematics for Generating Multi-Constrained Movements of Virtual Human Characters"

Code Coming Soon

[More Information](https://hvoss-techfak.github.io/TF-JAX-IK/)

# LICENSE
<a href="https://github.com/hvoss-techfak/TF-JAX-IK">Real-Time Inverse Kinematics for Generating Multi-Constrained Movements of Virtual Human Characters</a> © 2025 by <a href="https://github.com/hvoss-techfak">Hendric Voss</a> is licensed under <a href="https://creativecommons.org/licenses/by-nc-sa/4.0/">CC BY-NC-SA 4.0</a><img src="https://mirrors.creativecommons.org/presskit/icons/cc.svg" alt="" style="max-width: 1em;max-height:1em;margin-left: .2em;"><img src="https://mirrors.creativecommons.org/presskit/icons/by.svg" alt="" style="max-width: 1em;max-height:1em;margin-left: .2em;"><img src="https://mirrors.creativecommons.org/presskit/icons/nc.svg" alt="" style="max-width: 1em;max-height:1em;margin-left: .2em;"><img src="https://mirrors.creativecommons.org/presskit/icons/sa.svg" alt="" style="max-width: 1em;max-height:1em;margin-left: .2em;">
